<?php
/**
 * Package Section options
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */

// Add Package section
$wp_customize->add_section( 'travel_ultimate_pro_package_section', array(
	'title'             => esc_html__( 'Packages','travel-ultimate-pro' ),
	'description'       => esc_html__( 'Packages Section options.', 'travel-ultimate-pro' ),
	'panel'             => 'travel_ultimate_pro_front_page_panel',
) );

// Package content enable control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_section_enable]', array(
	'default'			=> 	$options['package_section_enable'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new travel_ultimate_pro_Switch_Control( $wp_customize, 'travel_ultimate_pro_theme_options[package_section_enable]', array(
	'label'             => esc_html__( 'Package Section Enable', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_package_section',
	'on_off_label' 		=> travel_ultimate_pro_switch_options(),
) ) );

// package title setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[package_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_package_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[package_title]', array(
		'selector'            => '#recommended-packages .section-header h2.section-title',
		'settings'            => 'travel_ultimate_pro_theme_options[package_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_package_title_partial',
    ) );
}

// package sub_title setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[package_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_package_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[package_sub_title]', array(
		'selector'            => '#recommended-packages .section-header span.section-subtitle',
		'settings'            => 'travel_ultimate_pro_theme_options[package_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_package_sub_title_partial',
    ) );
}

// package content type control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_column]', array(
	'default'          	=> $options['package_column'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[package_column]', array(
	'label'             => esc_html__( 'Column Layout', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_ultimate_pro_is_package_section_enable',
	'choices'			=> array( 
		'col-1'		=> esc_html__( 'One Column', 'travel-ultimate-pro' ),
		'col-2'		=> esc_html__( 'Two Column', 'travel-ultimate-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'travel-ultimate-pro' ),
	),
) );

// Package content type control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_content_type]', array(
	'default'          	=> $options['package_content_type'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_select',
) );

$choices = array( 
		'page' 		=> esc_html__( 'Page', 'travel-ultimate-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-ultimate-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-ultimate-pro' ),
	);
if ( class_exists( 'WP_Travel' ) ) {
	$choices['trip'] = esc_html__( 'Trip', 'travel-ultimate-pro' );
}
$wp_customize->add_control( 'travel_ultimate_pro_theme_options[package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_ultimate_pro_is_package_section_enable',
	'choices'			=> $choices,
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_count]', array(
	'default'          	=> $options['package_count'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_number_range',
	'validate_callback' => 'travel_ultimate_pro_validate_package_count',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[package_count]', array(
	'label'             => esc_html__( 'Number of Packages', 'travel-ultimate-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_package_section',
	'active_callback'   => 'travel_ultimate_pro_is_package_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['package_count']; $i++ ) :

	// package pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
	) );

	$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[package_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-ultimate-pro' ), $i ),
		'section'           => 'travel_ultimate_pro_package_section',
		'choices'			=> travel_ultimate_pro_page_choices(),
		'active_callback'	=> 'travel_ultimate_pro_is_package_section_content_page_enable',
	) ) );

	// package posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
	) );

	$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[package_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-ultimate-pro' ), $i ),
		'section'           => 'travel_ultimate_pro_package_section',
		'choices'			=> travel_ultimate_pro_post_choices(),
		'active_callback'	=> 'travel_ultimate_pro_is_package_section_content_post_enable',
	) ) );

	if ( class_exists( 'WP_Travel' ) ) {
		// slider trip drop down chooser control and setting
		$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_content_trip_' . $i . ']', array(
			'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
		) );

		$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[package_content_trip_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Trip %d', 'travel-ultimate-pro' ), $i ),
			'section'           => 'travel_ultimate_pro_package_section',
			'choices'			=> travel_ultimate_pro_trip_choices(),
			'active_callback'	=> 'travel_ultimate_pro_is_package_section_content_trip_enable',
		) ) );
	}

	// slider read more setting and control
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_read_more_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_ultimate_pro_theme_options[package_read_more_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Read more %d', 'travel-ultimate-pro' ), $i ),
		'section'        	=> 'travel_ultimate_pro_package_section',
		'active_callback' 	=> 'travel_ultimate_pro_is_package_section_enable',
		'type'				=> 'text',
	) );

	// package hr setting and control
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new travel_ultimate_pro_Customize_Horizontal_Line( $wp_customize, 'travel_ultimate_pro_theme_options[package_hr_'. $i .']',
		array(
			'section'         => 'travel_ultimate_pro_package_section',
			'active_callback' => 'travel_ultimate_pro_is_package_section_enable',
			'type'			  => 'hr'
	) ) );


endfor;

// package button text setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_btn_txt]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['package_btn_txt'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[package_btn_txt]', array(
	'label'             => esc_html__( 'Button text', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_package_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[package_btn_txt]', array(
		'selector'            => '#recommended-packages .view-all',
		'settings'            => 'travel_ultimate_pro_theme_options[package_btn_txt]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_package_btn_txt_partial',
    ) );
}

// package button url setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[package_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'          	=> $options['package_btn_url'],
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[package_btn_url]', array(
	'label'             => esc_html__( 'Button url', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_package_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_package_section_enable',
	'type'				=> 'url',
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[package_content_category]', array(
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[package_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-ultimate-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_package_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_ultimate_pro_is_package_section_content_category_enable'
) ) );
